@@ -1,4 +1,4 @@
-package Pcore::API::Moz v0.4.1;
+package Pcore::API::Moz v0.4.2;
 
 use Pcore -dist, -class;
 use Pcore::API::Response;
@@ -8,7 +8,7 @@ use Pcore::HTTP::CookieJar;
 has api_id      => ( is => 'ro', isa => Str,         required => 1 );
 has api_key     => ( is => 'ro', isa => Str,         required => 1 );
 has api_expires => ( is => 'ro', isa => PositiveInt, default  => 172_800 );    # 2 days
-has proxy_pool => ( is => 'ro', isa => Maybe [ InstanceOf ['Pcore::API::ProxyPool'] ], init_arg => undef );
+has proxy_pool => ( is => 'ro', isa => Maybe [ InstanceOf ['Pcore::API::ProxyPool'] ] );
 
 has _threads => ( is => 'ro', isa => PositiveOrZeroInt, default => 0, init_arg => undef );
 has _pool => ( is => 'ro', isa => ArrayRef, default => sub { [] }, init_arg => undef );
